@@ -146,6 +146,9 @@ class Animate:
         # draw axes at the origin
         base.trplot(self.start, ax=self, **kwargs)
 
+    def set_proj_type(self, proj_type):
+        self.ax.set_proj_type(proj_type)
+
     def run(
         self,
         movie=None,
@@ -260,7 +263,10 @@ class Animate:
         :returns: readable version of the display list
         :rtype: str
         """
-        return ", ".join([x.type for x in self.displaylist])
+        return "Animate(" + ", ".join([x.type for x in self.displaylist]) + ")"
+
+    def __str__(self):
+        return f"Animate(len={len(self.displaylist)}"
 
     def artists(self):
         """
@@ -628,7 +634,10 @@ class Animate2:
         :returns: readable version of the display list
         :rtype: str
         """
-        return ", ".join([x.type for x in self.displaylist])
+        return "Animate2(" + ", ".join([x.type for x in self.displaylist]) + ")"
+
+    def __str__(self):
+        return f"Animate2(len={len(self.displaylist)}"
 
     def artists(self):
         """
