@@ -251,10 +251,12 @@ class SE2(SO2):
         """
         Construct new SE(2) object
 
-        :param unit: angular units 'deg' or 'rad' [default] if applicable :type
-        unit: str, optional :param check: check for valid SE(2) elements if
-        applicable, default to True :type check: bool :return: homogeneous
-        rigid-body transformation matrix :rtype: SE2 instance
+        :param unit: angular units 'deg' or 'rad' [default] if applicable 
+        :type unit: str, optional 
+        :param check: check for valid SE(2) elements if applicable, default to True 
+        :type check: bool 
+        :return: SE(2) matrix 
+        :rtype: SE2 instance
 
         - ``SE2()`` is an SE2 instance representing a null motion -- the
           identity matrix
@@ -398,6 +400,33 @@ class SE2(SO2):
         else:
             return cls(base.trexp2(S), check=False)
 
+    @classmethod
+    def Rot(cls, theta, unit="rad"):
+        """
+        Create an SE(2) rotation
+
+        :param theta: rotation angle in radians
+        :type theta: float
+        :param unit: angular units: "rad" [default] or "deg"
+        :type unit: str
+        :return: SE(2) matrix
+        :rtype: SE2 instance
+
+        `SE2.Rot(theta)` is an SE(2) rotation of ``theta``
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> SE2.Rot(0.3)
+            >>> SE2.Rot([0.2, 0.3])
+
+
+        :seealso: :func:`~spatialmath.base.transforms3d.transl`
+        :SymPy: supported
+        """
+        return cls([base.trot2(_th, unit=unit) for _th in base.getvector(theta)], check=False)
+
     @classmethod
     def Tx(cls, x):
         """
@@ -512,7 +541,7 @@ class SE2(SO2):
 
         Notes:
 
-            - for elements of SE(2) this takes into account the matrix structure :math:`T^{-1} = \left[ \begin{array}{cc} R & t \\ 0 & 1 \end{array} \right], T^{-1} = \left[ \begin{array}{cc} R^T & -R^T t \\ 0 & 1 \end{array} \right]`
+            - for elements of SE(2) this takes into account the matrix structure :math:`T = \left[ \begin{array}{cc} R & t \\ 0 & 1 \end{array} \right], T^{-1} = \left[ \begin{array}{cc} R^T & -R^T t \\ 0 & 1 \end{array} \right]`
             - if `x` contains a sequence, returns an `SE2` with a sequence of inverses
 
         """
