@@ -408,7 +408,7 @@ class SO3(BasePoseMatrix):
 
         :seealso: :func:`spatialmath.quaternion.UnitQuaternion.Rand`
         """
-        return cls([base.q2r(base.rand()) for _ in range(0, N)], check=False)
+        return cls([base.q2r(base.qrand()) for _ in range(0, N)], check=False)
 
     @classmethod
     def Eul(cls, *angles, unit='rad'):
@@ -536,6 +536,69 @@ class SO3(BasePoseMatrix):
         """
         return cls(base.oa2r(o, a), check=False)
 
+    @classmethod
+    def TwoVectors(cls, x=None, y=None, z=None):
+        """
+        Construct a new SO(3) from any two vectors
+
+        :param x: new x-axis, defaults to None
+        :type x: str, array_like(3), optional
+        :param y: new y-axis, defaults to None
+        :type y: str, array_like(3), optional
+        :param z: new z-axis, defaults to None
+        :type z: str, array_like(3), optional
+
+        Create a rotation by defining the direction of two of the new
+        axes in terms of the old axes.  Axes are denoted by strings ``"x"``, 
+        ``"y"``, ``"z"``, ``"-x"``, ``"-y"``, ``"-z"``.
+
+        The directions can also be specified by 3-element vectors, but these
+        must be orthogonal.
+
+        To create a rotation where the new frame has its x-axis in -z-direction
+        of the previous frame, and its z-axis in the x-direction of the previous
+        frame is::
+        
+            >>> SO3.TwoVectors(x='-z', z='x')
+        """
+        def vval(v):
+            if isinstance(v, str):
+                sign = 1
+                if v[0] == '-':
+                    sign = -1
+                    v = v[1:] # skip sign char
+                elif v[0] == '+':
+                    v = v[1:] # skip sign char
+                if v[0] == 'x':
+                    v = [sign, 0, 0]
+                elif v[0] == 'y':
+                    v = [0, sign, 0]
+                elif v[0] == 'z':
+                    v = [0, 0, sign]
+                return np.r_[v]
+            else:
+                return base.unitvec(base.getvector(v, 3))
+
+        if x is not None and y is not None and z is None:
+            # z = x x y
+            x = vval(x)
+            y = vval(y)
+            z = np.cross(x, y)
+
+        elif x is None and y is not None and z is not None:
+            # x = y x z
+            y = vval(y)
+            z = vval(z)
+            x = np.cross(y, z)
+
+        elif x is not None and y is None and z is not None:
+            # y = z x x
+            z = vval(z)
+            x = vval(x)
+            y = np.cross(z, x)
+
+        return cls(np.c_[x, y, z], check=False)
+
     @classmethod
     def AngleAxis(cls, theta, v, *, unit='rad'):
         r"""
@@ -680,7 +743,7 @@ class SO3(BasePoseMatrix):
 
         .. runblock:: pycon
 
-            >>> from spatialmath import UnitQuaternion
+            >>> from spatialmath import SO3
             >>> R1 = SO3.Rx(0.3)
             >>> R2 = SO3.Ry(0.3)
             >>> print(R1.angdist(R1))
@@ -812,18 +875,15 @@ class SE3(SO3):
         ``x.t`` is the translational component of ``x`` as an array with
         shape (3,). If ``len(x) > 1``, return an array with shape=(N,3).
 
+        Example:
+
         .. runblock:: pycon
 
-            >>> from spatialmath import UnitQuaternion
-
+            >>> from spatialmath import SE3
             >>> x = SE3(1,2,3)
             >>> x.t
-            array([1., 2., 3.])
             >>> x = SE3([ SE3(1,2,3), SE3(4,5,6)])
             >>> x.t
-            array([[1., 2., 3.],
-                   [4., 5., 6.]])
-
         
         :SymPy: supported
         """
@@ -832,6 +892,12 @@ class SE3(SO3):
         else:
             return np.array([x[:3, 3] for x in self.A])
 
+    @t.setter
+    def t(self, v):
+        if len(self) > 1:
+            raise ValueError("can only assign translation to length 1 object")
+        v = base.getvector(v, 3)
+        self.A[:3, 3] = v
     # ------------------------------------------------------------------------ #
 
     def inv(self):
@@ -849,14 +915,14 @@ class SE3(SO3):
             T = \left[ \begin{array}{cc} \mat{R} & \vec{t} \\ 0 & 1 \end{array} \right],
             \mat{T}^{-1} = \left[ \begin{array}{cc} \mat{R}^T & -\mat{R}^T \vec{t} \\ 0 & 1 \end{array} \right]`
 
-        Example::
+        Example:
 
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3
             >>> x = SE3(1,2,3)
             >>> x.inv()
-            SE3(array([[ 1.,  0.,  0., -1.],
-                       [ 0.,  1.,  0., -2.],
-                       [ 0.,  0.,  1., -3.],
-                       [ 0.,  0.,  0.,  1.]]))
+
 
         :seealso: :func:`~spatialmath.base.transforms3d.trinv`
 
@@ -867,7 +933,7 @@ class SE3(SO3):
         else:
             return SE3([base.trinv(x) for x in self.A], check=False)
 
-    def delta(self, X2):
+    def delta(self, X2=None):
         r"""
         Infinitesimal difference of SE(3) values
 
@@ -880,13 +946,15 @@ class SE3(SO3):
         The vector :math:`d = [\delta_x, \delta_y, \delta_z, \theta_x, \theta_y, \theta_z]`
         represents infinitesimal translation and rotation.
 
-        Example::
+        Example:
 
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3
             >>> x1 = SE3.Rx(0.3)
             >>> x2 = SE3.Rx(0.3001)
             >>> x1.delta(x2)
-            array([0.00000000e+00, 0.00000000e+00, 0.00000000e+00, 9.99999998e-05,
-                0.00000000e+00, 0.00000000e+00])
+
 
         .. note::
 
@@ -899,10 +967,13 @@ class SE3(SO3):
 
         :seealso: :func:`~spatialmath.base.transforms3d.tr2delta`
         """
-        return base.tr2delta(self.A, X2.A)
+        if X2 is None:
+            return base.tr2delta(self.A)
+        else:
+            return base.tr2delta(self.A, X2.A)
 
     def Ad(self):
-        """
+        r"""
         Adjoint of SE(3)
 
         :return: adjoint matrix
@@ -928,7 +999,7 @@ class SE3(SO3):
         return base.tr2adjoint(self.A)
 
     def jacob(self):
-        """
+        r"""
         Velocity transform for SE(3)
 
         :return: Jacobian matrix
@@ -960,11 +1031,13 @@ class SE3(SO3):
         :return: equivalent rigid-body motion as a twist vector
         :rtype: Twist3 instance
 
-        Example::
+        Example:
 
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3
             >>> x = SE3(1,2,3)
             >>> x.twist()
-            Twist3([1, 2, 3, 0, 0, 0])
 
         :seealso: :func:`spatialmath.twist.Twist3`
         """
@@ -1017,6 +1090,7 @@ class SE3(SO3):
 
         .. runblock:: pycon
 
+            >>> from spatialmath import SE3
             >>> SE3.Rx(0.3)
             >>> SE3.Rx([0.3, 0.4])
 
@@ -1052,6 +1126,7 @@ class SE3(SO3):
 
         .. runblock:: pycon
 
+            >>> from spatialmath import SE3
             >>> SE3.Ry(0.3)
             >>> SE3.Ry([0.3, 0.4])
 
@@ -1087,6 +1162,7 @@ class SE3(SO3):
 
         .. runblock:: pycon
 
+            >>> from spatialmath import SE3
             >>> SE3.Rz(0.3)
             >>> SE3.Rz([0.3, 0.4])
 
@@ -1117,18 +1193,13 @@ class SE3(SO3):
         - ``SE3.Rand(N)`` is an SE3 object containing a sequence of N random
           poses.
 
-        Example::
 
+        Example:
+
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3
             >>> SE3.Rand(2)
-            SE3([
-            array([[ 0.58076657,  0.64578702, -0.49565041, -0.78585825],
-                [-0.57373134, -0.10724881, -0.8119914 ,  0.72069253],
-                [-0.57753142,  0.75594763,  0.30822173,  0.12291999],
-                [ 0.        ,  0.        ,  0.        ,  1.        ]]),
-            array([[ 0.96481299, -0.26267256, -0.01179066,  0.80294729],
-                [ 0.06421463,  0.19190584,  0.97931028, -0.15021311],
-                [-0.25497525, -0.94560841,  0.20202067,  0.02684599],
-                [ 0.        ,  0.        ,  0.        ,  1.        ]]) ])
 
         :seealso: :func:`~spatialmath.quaternions.UnitQuaternion.Rand`
         """
@@ -1261,13 +1332,12 @@ class SE3(SO3):
             - ``o`` and ``a`` do not have to be orthogonal, so long as they are not parallel
               ``o`` is adjusted to be orthogonal to ``a``.
 
-        Example::
+        Example:
 
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3
             >>> SE3.OA([1, 0, 0], [0, 0, -1])
-            SE3(array([[-0.,  1.,  0.,  0.],
-                    [ 1.,  0.,  0.,  0.],
-                    [ 0.,  0., -1.,  0.],
-                    [ 0.,  0.,  0.,  1.]]))
 
         :seealso: :func:`~spatialmath.base.transforms3d.oa2r`
         """
@@ -1391,16 +1461,46 @@ class SE3(SO3):
         :rtype: SE3 instance
 
 
-        ``T = delta2tr(d)`` is an SE(3) representing differential 
+        ``SE3.Delta2tr(d)`` is an SE(3) representing differential 
         motion :math:`d = [\delta_x, \delta_y, \delta_z, \theta_x, \theta_y, \theta_z]`.
 
         :Reference: Robotics, Vision & Control: Second Edition, P. Corke, Springer 2016; p67.
 
-        :seealso: :func:`~delta`, :func:`~spatialmath.base.transform3d.delta2tr`
+        :seealso: :meth:`~delta` :func:`~spatialmath.base.transform3d.delta2tr`
         :SymPy: supported
         """
         return cls(base.trnorm(base.delta2tr(d)))
 
+    @classmethod
+    def Trans(cls, x, y=None, z=None):
+        """
+        Create SE(3) from translation vector
+
+        :param x: x-coordinate or translation vector
+        :type x: float or array_like(3)
+        :param y: y-coordinate, defaults to None
+        :type y: float, optional
+        :param z: z-coordinate, defaults to None
+        :type z: float, optional
+        :return: SE(3) matrix
+        :rtype: SE3 instance
+
+        - ``SE3.Trans(x, y, z)`` is an SE(3) representing pure translation.
+
+        - ``SE3.Trans([x, y, z])`` as above, but translation is given as an
+          array.
+
+        - ``SE3.Trans(t)`` where ``t`` is Nx3 then create an SE3 object with
+          N elements whose translation is defined by the rows of ``t``.
+
+        """
+        if y is None and z is None:
+            # single passed value, assume is 3-vector or Nx3
+            t = base.getmatrix(x, (None, 3))
+            return cls([base.transl(_t) for _t in t], check=False)
+        else:
+            return cls(np.array([x, y, z]))
+
     @classmethod
     def Tx(cls, x):
         """
@@ -1417,6 +1517,7 @@ class SE3(SO3):
 
         .. runblock:: pycon
 
+            >>> from spatialmath import SE3
             >>> SE3.Tx(2)
             >>> SE3.Tx([2,3])
 
@@ -1443,6 +1544,7 @@ class SE3(SO3):
 
         .. runblock:: pycon
 
+            >>> from spatialmath import SE3
             >>> SE3.Ty(2)
             >>> SE3.Ty([2,3])
 
@@ -1468,6 +1570,7 @@ class SE3(SO3):
 
         .. runblock:: pycon
 
+            >>> from spatialmath import SE3
             >>> SE3.Tz(2)
             >>> SE3.Tz([2,3])
 
@@ -1477,7 +1580,7 @@ class SE3(SO3):
         return cls([base.transl(0, 0, _z) for _z in base.getvector(z)], check=False)
 
     @classmethod
-    def Rt(cls, R, t, check=True):
+    def Rt(cls, R, t=None, check=True):
         """
         Create an SE(3) from rotation and translation
 
@@ -1498,7 +1601,9 @@ class SE3(SO3):
         else:
             raise ValueError('expecting SO3 or rotation matrix')
 
-        return cls(base.rt2tr(R, t))
+        if t is None:
+            t = np.zeros((3,))
+        return cls(base.rt2tr(R, t, check=check), check=check)
 
     def angdist(self, other, metric=6):
         r"""
@@ -1534,7 +1639,7 @@ class SE3(SO3):
 
         .. runblock:: pycon
 
-            >>> from spatialmath import UnitQuaternion
+            >>> from spatialmath import SE3
             >>> T1 = SE3.Rx(0.3)
             >>> T2 = SE3.Ry(0.3)
             >>> print(T1.angdist(T1))
