@@ -138,7 +138,7 @@ class BaseTwist(BasePoseList):
 
     @property
     def isunit(self):
-        """
+        r"""
         Test for unit twist (superclass property)
 
         :return: Whether twist is a unit-twist
@@ -282,7 +282,7 @@ class BaseTwist(BasePoseList):
 
     def __truediv__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         if base.isscalar(right):
-            return Twist3(left.S / right)
+            return type(left)(left.S / right)
         else:
             raise ValueError('Twist /, incorrect right operand')
 
@@ -825,15 +825,16 @@ class Twist3(BaseTwist):
 
 
 
-    def se3(self):
+    def skewa(self):
         """
         Convert 3D twist to se(3)
 
         :return: An se(3) matrix
         :rtype: ndarray(4,4)
 
-        ``X.se3()`` is the twist as an se(3) matrix, which is an augmented
-        skew-symmetric 4x4 matrix.
+        ``X.skewa()`` is the twist as a 4x4 augmented skew-symmetric matrix
+        belonging to the group se(3). This is the Lie algebra of the
+        corresponding SE(3) element. 
 
         Example:
         
@@ -841,7 +842,7 @@ class Twist3(BaseTwist):
 
             >>> from spatialmath import Twist3, base
             >>> S = Twist3.Rx(0.3)
-            >>> se = S.se3()
+            >>> se = S.skewa()
             >>> se
             >>> base.trexp(se)
         """
@@ -970,6 +971,15 @@ class Twist3(BaseTwist):
         - ``X.exp(θ) as above but with a rotation of ``θ`` about the twist axis,
           :math:`e^{\theta[S]}`
 
+        If ``len(X)==1`` and ``len(θ)==N`` then the resulting SE3 object has
+        ``N`` values equivalent to the twist :math:`e^{\theta_i[S]}`.
+
+        If ``len(X)==N`` and ``len(θ)==1`` then the resulting SE3 object has
+        ``N`` values equivalent to the twist :math:`e^{\theta[S_i]}`.
+
+        If ``len(X)==N`` and ``len(θ)==N`` then the resulting SE3 object has
+        ``N`` values equivalent to the twist :math:`e^{\theta_i[S_i]}`.
+
         Example:
         
         .. runblock:: pycon
@@ -987,9 +997,15 @@ class Twist3(BaseTwist):
 
         :seealso: :func:`spatialmath.base.trexp`
         """
-        theta = base.getunit(theta, unit)
+        theta = np.r_[base.getunit(theta, unit)]
+
+        if len(self) == 1:
+            return SE3([base.trexp(self.S * t) for t in theta], check=False)
+        elif len(self) == len(theta):
+            return SE3([base.trexp(s * t) for s, t in zip(self.S, theta)], check=False)
+        else:
+            raise ValueError('length mismatch')
 
-        return base.trexp(self.S * theta)
 
 
     # ------------------------- arithmetic -------------------------------#
@@ -1421,15 +1437,16 @@ class Twist2(BaseTwist):
         else:
             return SE2([base.trexp2(self.S * t) for t in theta])
 
-    def se2(self):
+    def skewa(self):
         """
         Convert 2D twist to se(2)
 
         :return: An se(2) matrix
         :rtype: ndarray(3,3)
 
-        ``X.se2()`` is the twist as an se(2) matrix, which is an augmented
-        skew-symmetric 3x3 matrix.
+        ``X.skewa()`` is the twist as a 3x3 augmented skew-symmetric matrix
+        belonging to the group se(2). This is the Lie algebra of the
+        corresponding SE(2) element. 
 
         Example:
         
@@ -1437,7 +1454,7 @@ class Twist2(BaseTwist):
 
             >>> from spatialmath import Twist2, base
             >>> S = Twist2([1,2,3])
-            >>> se = S.se2()
+            >>> se = S.skewa()
             >>> se
             >>> base.trexp2(se)
         """
@@ -1484,7 +1501,7 @@ class Twist2(BaseTwist):
         else:
             theta = base.getunit(theta, unit)
 
-        return base.trexp2(self.S * theta)
+        return SE2(base.trexp2(self.S * theta))
 
 
     def unit(self):
@@ -1714,4 +1731,4 @@ if __name__ == '__main__':   # pragma: no cover
 
     # import pathlib
 
-    # exec(open(pathlib.Path(__file__).parent.parent.absolute() / "tests" / "test_twist.py").read())  # pylint: disable=exec-used
\ No newline at end of file
+    # exec(open(pathlib.Path(__file__).parent.parent.absolute() / "tests" / "test_twist.py").read())  # pylint: disable=exec-used
